#include "HeliosConfigView.h"
#include "HLM.h"
#include "Application1.h"

extern HLM *H;

#define SPEEDSLIDER_CHANGED	'HCV0'
#define FIFOSLIDER_CHANGED	'HCV1'
#define DAO_MSG			'HCV2'

HeliosConfigView::HeliosConfigView() : ConfigView(){
	// CHECKBOXES
	simulationCB=new BCheckBox(BRect(15,5,230,20), "hcv_simulationCB", H->L("TSIMULATION"), NULL);
	AddChild(simulationCB);
	fixatingCB=new BCheckBox(BRect(15,25,230,40), "hcv_fixatingCB", H->L("TFIXATE"), NULL);
	AddChild(fixatingCB);
	burnproofCB=new BCheckBox(BRect(15,45,230,60), "hcv_burnproofCB", H->L("TBURNPROOF"), NULL);
	AddChild(burnproofCB);
	forcedCB=new BCheckBox(BRect(15, 65, 230, 80), "hcv_forcedCB", H->L("TFORCEOPTION"), NULL);
	AddChild(forcedCB);
	DAOCB=new BCheckBox(BRect(15,85,230,100), "hcv_DAOCB", H->L("TDAOMODE"), new BMessage(DAO_MSG));
	AddChild(DAOCB);
	overburningCB=new BCheckBox(BRect(15,105,230,120), "hcv_overburningCB", H->L("TALLOWOVERBURNING"), NULL);
	AddChild(overburningCB);
	
	// SLIDERS
	speedSL=new BSlider(BRect(15, 164, 325, 198), "hcv_speedSL", NULL, new BMessage(SPEEDSLIDER_CHANGED), 0, 24);
	speedSL->SetHashMarks(B_HASH_MARKS_BOTTOM);
	speedSL->SetHashMarkCount(25);
	speedSL->SetKeyIncrementValue(1);
	speedSL->SetLimitLabels("1x", "48x");
	AddChild(speedSL);
	fifoSL=new BSlider(BRect(15, 216, 325, 250), "hcv_fifoSL", NULL, new BMessage(FIFOSLIDER_CHANGED), 1, 32);
	fifoSL->SetHashMarks(B_HASH_MARKS_BOTTOM);
	fifoSL->SetHashMarkCount(32);
	fifoSL->SetKeyIncrementValue(1);
	fifoSL->SetLimitLabels("1MB", "32MB");
	AddChild(fifoSL);
	
	// STRINGVIEWS
	speedSV=new BStringView(BRect(15,148,300,163), "speedSV", "");
	AddChild(speedSV);
	fifoSV=new BStringView(BRect(15,200,300,215), "fifoSV", "");
	AddChild(fifoSV);
}

HeliosConfigView::~HeliosConfigView() {
}
	
bool	HeliosConfigView::IsSimulation() {
	return simulationCB->Value()==B_CONTROL_ON;
}

void	HeliosConfigView::SetSimulation(bool state) {
	simulationCB->SetValue(state ? B_CONTROL_ON : B_CONTROL_OFF);
}
	
bool	HeliosConfigView::IsFixating() {
	return fixatingCB->Value()==B_CONTROL_ON;
}

void	HeliosConfigView::SetFixating(bool state) {
	fixatingCB->SetValue(state ? B_CONTROL_ON : B_CONTROL_OFF);
}

bool	HeliosConfigView::IsBurnproof() {
	return burnproofCB->Value()==B_CONTROL_ON;
}

void	HeliosConfigView::SetBurnproof(bool state) {
	burnproofCB->SetValue(state ? B_CONTROL_ON : B_CONTROL_OFF);
}
	
bool	HeliosConfigView::IsDAO() {
	return DAOCB->Value()==B_CONTROL_ON;
}

void	HeliosConfigView::SetDAO(bool state) {
	DAOCB->SetValue(state ? B_CONTROL_ON : B_CONTROL_OFF);
}

bool	HeliosConfigView::IsOverburning() {
	return overburningCB->Value()==B_CONTROL_ON;
}

void	HeliosConfigView::SetOverburning(bool state) {
	overburningCB->SetValue(state ? B_CONTROL_ON : B_CONTROL_OFF);
}

int32	HeliosConfigView::GetWriterSpeed() {
	if (speedSL->Value()==0)
		return 1;
	else
		return speedSL->Value()*2;
}

void	HeliosConfigView::SetWriterSpeed(int32 speed) {
	if (speed==1)
		speedSL->SetValue(0);
	else
		speedSL->SetValue(speed/2);
	string=H->L("TRECORDERSPEED");
	string << " (" << speed << "x)";
	speedSV->SetText(string.String());
}

int8	HeliosConfigView::GetFIFOSize() {
	return fifoSL->Value();
}

void	HeliosConfigView::SetFIFOSize(int8 size) {
	fifoSL->SetValue(size);
	string=H->L("TBUFFERSIZE");
	string << " " << size << " MB";
	fifoSV->SetText(string.String());
}

bool	HeliosConfigView::IsForcedErasing() {
	return forcedCB->Value()==B_CONTROL_ON;
}

void	HeliosConfigView::SetForcedErasing(bool state) {
	forcedCB->SetValue(state ? B_CONTROL_ON : B_CONTROL_OFF);
}

// PRIVATE

void	HeliosConfigView::AllAttached() {
	speedSL->SetModificationMessage(new BMessage(SPEEDSLIDER_CHANGED));
	speedSL->SetTarget(this);
	fifoSL->SetModificationMessage(new BMessage(FIFOSLIDER_CHANGED));
	fifoSL->SetTarget(this);
	DAOCB->SetTarget(this, Looper());
	ConfigView::AllAttached();
}

void	HeliosConfigView::MessageReceived(BMessage *msg) {
	switch(msg->what) {
		case FIFOSLIDER_CHANGED: {
			SetFIFOSize(GetFIFOSize());
			break;
		}
		case SPEEDSLIDER_CHANGED: {
			SetWriterSpeed(GetWriterSpeed());
			break;
		}
		case DAO_MSG: {
			Application1 *app=(Application1 *)be_app;
			
			if (app->window1->Lock()) {
				if (app->window1->view1->datapanel->IsMultisession()) {
					app->window1->view1->datapanel->SetMultisession(false);
					if (app->window1->Lock()) {
						app->window1->view1->statusBAR->SetText(H->L("L:Multisession disabled."), 4000000);
						app->window1->Unlock();
					}
				}
				app->window1->Unlock();
			}
			break;
		}
		default: {
			BView::MessageReceived(msg);
			break;
		}
	}
}


void	HeliosConfigView::GetSettings(BMessage *archive) {
	// CHECKBOXES
	archive->AddBool("HeliosConfigView::hcv_simulationCB", ((BCheckBox *)FindView("hcv_simulationCB"))->Value()==B_CONTROL_ON);
	archive->AddBool("HeliosConfigView::hcv_fixatingCB", ((BCheckBox *)FindView("hcv_fixatingCB"))->Value()==B_CONTROL_ON);
	archive->AddBool("HeliosConfigView::hcv_burnproofCB", ((BCheckBox *)FindView("hcv_burnproofCB"))->Value()==B_CONTROL_ON);
	archive->AddBool("HeliosConfigView::hcv_forcedCB", ((BCheckBox *)FindView("hcv_forcedCB"))->Value()==B_CONTROL_ON);
	archive->AddBool("HeliosConfigView::hcv_DAOCB", ((BCheckBox *)FindView("hcv_DAOCB"))->Value()==B_CONTROL_ON);
	archive->AddBool("HeliosConfigView::hcv_overburningCB", ((BCheckBox *)FindView("hcv_overburningCB"))->Value()==B_CONTROL_ON);

	// SLIDERS
	archive->AddInt32("HeliosConfigView::hcv_speedSL", ((BSlider *)FindView("hcv_speedSL"))->Value());
	archive->AddInt32("HeliosConfigView::hcv_fifoSL", ((BSlider *)FindView("hcv_fifoSL"))->Value());
}

void	HeliosConfigView::SetSettings(BMessage *archive) {
	bool	boolvar;
	int32	int32var;

	// CHECKBOXES
	if (archive->FindBool("HeliosConfigView::hcv_simulationCB", &boolvar)==B_OK)
		((BCheckBox *)FindView("hcv_simulationCB"))->SetValue(boolvar?B_CONTROL_ON:B_CONTROL_OFF);
	else
		((BCheckBox *)FindView("hcv_simulationCB"))->SetValue(B_CONTROL_OFF);
	if (archive->FindBool("HeliosConfigView::hcv_fixatingCB", &boolvar)==B_OK)
		((BCheckBox *)FindView("hcv_fixatingCB"))->SetValue(boolvar?B_CONTROL_ON:B_CONTROL_OFF);
	else
		((BCheckBox *)FindView("hcv_fixatingCB"))->SetValue(B_CONTROL_ON);
	if (archive->FindBool("HeliosConfigView::hcv_burnproofCB", &boolvar)==B_OK)
		((BCheckBox *)FindView("hcv_burnproofCB"))->SetValue(boolvar?B_CONTROL_ON:B_CONTROL_OFF);
	else
		((BCheckBox *)FindView("hcv_burnproofCB"))->SetValue(B_CONTROL_OFF);
	if (archive->FindBool("HeliosConfigView::hcv_forcedCB", &boolvar)==B_OK)
		((BCheckBox *)FindView("hcv_forcedCB"))->SetValue(boolvar?B_CONTROL_ON:B_CONTROL_OFF);
	else
		((BCheckBox *)FindView("hcv_forcedCB"))->SetValue(B_CONTROL_OFF);
	if (archive->FindBool("HeliosConfigView::hcv_DAOCB", &boolvar)==B_OK)
		((BCheckBox *)FindView("hcv_DAOCB"))->SetValue(boolvar?B_CONTROL_ON:B_CONTROL_OFF);
	else
		((BCheckBox *)FindView("hcv_DAOCB"))->SetValue(B_CONTROL_ON);
	if (archive->FindBool("HeliosConfigView::hcv_overburningCB", &boolvar)==B_OK)
		((BCheckBox *)FindView("hcv_overburningCB"))->SetValue(boolvar?B_CONTROL_ON:B_CONTROL_OFF);
	else
		((BCheckBox *)FindView("hcv_overburningCB"))->SetValue(B_CONTROL_OFF);

	if (archive->FindInt32("HeliosConfigView::hcv_speedSL", &int32var)==B_OK)
		((BSlider *)FindView("hcv_speedSL"))->SetValue(int32var);
	else
		((BSlider *)FindView("hcv_speedSL"))->SetValue(10);
	if (archive->FindInt32("HeliosConfigView::hcv_fifoSL", &int32var)==B_OK)
		((BSlider *)FindView("hcv_fifoSL"))->SetValue(int32var);
	else
		((BSlider *)FindView("hcv_fifoSL"))->SetValue(3);


	SetFIFOSize(GetFIFOSize());
	SetWriterSpeed(GetWriterSpeed());
}




